@@ -13,7 +13,7 @@ def delt(s):
 def ax_name(tab, qty):
     s = f"${qty}$"
     if not str(tab.units[qty]) == '1':
-        s += f" ( {tab.units[qty]} )"
+        s += r" ( ${:}$ )".format(tab.units[qty])
     return s
 
 
@@ -115,5 +115,9 @@ def fastPlot(file):
     plt.plot(array[:, 0], array[:, 1])
 
 
+def rejectOutliers(data, n=2):
+    return data[abs(data - np.mean(data)) < n * np.std(data)]
+
+
 def roll(values, min, max):
-    return ((values+min) % max)-min
+    return ((values-min) % (max-min))+min
